@@ -78,9 +78,9 @@
 #'        is explained by 1-nlarge weighted holdings, the grid cell will not pass the confidentiality rule.
 #'        
 #'        It is also possible to apply the p-percent rule. This rule defines a minimum percentage for how close the 
-#'        second largest produces could be of estimating the production of the largest producer by subtracting
+#'        second largest producer could be of estimating the production of the largest producer by subtracting
 #'        its own production from the total value of the cell. 
-#'        \deqn{Y_{cell}-Y_2-Y_1)/Y_1 < pPercent} 
+#'        \deqn{(Y_{cell}-Y_2-Y_1)/Y_1 < pPercent} 
 #'        where \eqn{Y_{cell}, Y_2, Y_1} represent the total production value of the cell,
 #'        the value of the second largest production, and the value of the largest production,
 #'        respectively.
@@ -140,8 +140,10 @@
 #'                 or potentially internal variables of \code{multiResGrid.})
 #'          \item The result of the function must be a logical, either the rule was passed 
 #'                for the records of this grid cell, or not (TRUE/FALSE)
-#'          \item The function can potentially use internal variables of \code{multiResGrid}, however,
-#'                the meaning of these will have to be understood from the code
+#'          \item The function can potentially use all internal variables in the internal function \code{confid}. 
+#'                Only the most useful will be mentioned here, meaning of the rest will have to be understood from the code.
+#'                
+#'          
 #'        }
 #'        A simple example of a \code{userfun} is given in the example section below (the one producing \code{himg6})
 #'        
@@ -231,7 +233,7 @@
 #' p31 = ggplot(himg3) + geom_sf(aes(fill = UAA))
 #' p32 = ggplot(himg3) + geom_sf(aes(fill = UAAXK0000_ORG))
 #' p33 = ggplot(himg33) + geom_sf(aes(fill = UAAXK0000_ORG))
-#' p31 + p32 + p33
+#' if (require(patchwork)) p31 + p32 + p33
 #' 
 #' # Create multi-resolution grid of UAA, based on survey data,
 #' # with and without applying reliability check
@@ -277,7 +279,7 @@
 #' p00 = ggplot() + geom_sf(data = himg00, aes(fill = count, color = count)) +
 #'   scale_fill_viridis( name = "number of farms", trans = "log10") +
 #'   scale_color_viridis( name = "number of farms", trans = "log10") +
-#'   coord_sf(crs = 3035) +#, xlim = c(2377294, 6400000), ylim = c(1313597, 5628510)) +
+#'   coord_sf(crs = 3035) +
 #'   ggtitle("Number of farms for variable grid cell size, only frequency confidentiality") +
 #'   theme_bw()
 #' if (useBorder) p00 = p00 + geom_sf(data = dkb, fill = NA, colour='black', lwd = 1) 
@@ -287,7 +289,7 @@
 #' p01 = ggplot() + geom_sf(data = himg01, aes(fill = count, color = count)) +
 #'   scale_fill_viridis( name = "number of farms", trans = "log10") +
 #'   scale_color_viridis( name = "number of farms", trans = "log10") +
-#'   coord_sf(crs = 3035) +#, xlim = c(2377294, 6400000), ylim = c(1313597, 5628510)) +
+#'   coord_sf(crs = 3035) +
 #'   ggtitle("Number of farms for variable grid cell size, frequency and dominance confidentiality") +
 #'   theme_bw()
 #' if (useBorder) p01 = p01 + geom_sf(data = dkb, fill = NA, colour='black', lwd = 1) 
@@ -299,7 +301,7 @@
 #' units(himg02$orgarea) = NULL
 #' p02 = ggplot() + geom_sf(data = himg02, aes(fill = orgarea), lwd = 0) +
 #'   scale_fill_viridis( name = "ha / km2") +
-#'   coord_sf(crs = 3035) +#, xlim = c(2377294, 6400000), ylim = c(1313597, 5628510)) +
+#'   coord_sf(crs = 3035) +
 #'   ggtitle("Organic UAA density")  +
 #'   theme_bw()
 #' if (useBorder) p02 = p02 + geom_sf(data = dkb, fill = NA, colour='black', lwd = 1) 
@@ -310,7 +312,7 @@
 #' himg03$ouaashare = himg03$UAAXK0000_ORG/himg03$UAA*100
 #' p03 = ggplot() + geom_sf(data = himg03, aes(fill = ouaashare), lwd = 0) +
 #'   scale_fill_viridis( name = "% Organic") +
-#'   coord_sf(crs = 3035) +#, xlim = c(2377294, 6400000), ylim = c(1313597, 5628510)) +
+#'   coord_sf(crs = 3035) +
 #'   ggtitle("Organic share")  +
 #'   theme_bw()
 #' if (useBorder) p03 = p03 + geom_sf(data = dkb, fill = NA, colour='black', lwd = 1) 
@@ -329,8 +331,7 @@
 #' himg04$uaashare[himg04$uaashare > 1000] = 1000
 #' p04 = ggplot() + geom_sf(data = himg04, aes(fill = uaashare), lwd = 0) +
 #'   scale_fill_viridis( name = "% UAA",  trans = "log10", limits = c(1,1000)) +
-#'   geom_sf(data = dkb, fill = NA, colour='black', lwd = 1) +
-#'   coord_sf(crs = 3035) +#, xlim = c(2377294, 6400000), ylim = c(1313597, 5628510)) +
+#'   coord_sf(crs = 3035) +
 #'   ggtitle("UAA share (sample without reliability check)")  +
 #'   theme_bw()
 #' if (useBorder) p04 = p04 + geom_sf(data = dkb, fill = NA, colour='black', lwd = 1) 
@@ -343,7 +344,7 @@
 #' himg05$uaashare[himg05$uaashare > 1000] = 1000
 #' p05 = ggplot() + geom_sf(data = himg05, aes(fill = uaashare), lwd = 0) +
 #'   scale_fill_viridis( name = "% UAA",  trans = "log10", limits = c(1,1000)) +
-#'   coord_sf(crs = 3035) +#, xlim = c(2377294, 6400000), ylim = c(1313597, 5628510)) +
+#'   coord_sf(crs = 3035) +
 #'   ggtitle("UAA share (sample with reliability check)")  +
 #'   theme_bw()
 #' if (useBorder) p05 = p05 + geom_sf(data = dkb, fill = NA, colour='black', lwd = 1) 
@@ -353,7 +354,7 @@
 #' if (useBorder) himg06 = st_intersection(dkb, himg6) else himg06 = himg6
 #' p06 = ggplot() + geom_sf(data = himg06, aes(fill = UAA), lwd = 0) +
 #'   scale_fill_viridis( name = "ha") +
-#'   coord_sf(crs = 3035) +#, xlim = c(2377294, 6400000), ylim = c(1313597, 5628510)) +
+#'   coord_sf(crs = 3035) +
 #'   ggtitle("UAA, with additional user defined function")  +
 #'   theme_bw()
 #' if (useBorder) p06 = p06 + geom_sf(data = dkb, fill = NA, colour='black', lwd = 1) 
@@ -536,24 +537,17 @@ multiResGrid.list <- function(MRGinp, ifg, vars, weights, countFeatureOrTotal =
     if (!missing(vars) & ires <= length(ress)) {
       for (ivar in 1:length(vars)){
         if (tolower(countFeatureOrTotal) == "feature") {
-          #          sel = (loh[[paste0(vars[ivar], "_w", ivar, ".x")]]  <
-          #                   suppresslim*loh[[paste0(vars[ivar], "_w", ivar, ".y")]]) & loh[[paste0("weight",ivar, ".x")]] < mincount
           sel = (loh[[paste0(vars[ivar], ".x")]]  <
-                   suppresslim*loh[[paste0(vars[ivar], ".y")]]) # & loh[[paste0("weight_",vars[ivar], ".x")]] < mincount
-          #        } else sel = (loh[[paste0(vars[ivar], "_w", ivar, ".x")]]  <
-          #                        suppresslim*loh[[paste0(vars[ivar], "_w", ivar, ".y")]]) & loh[["countw.x"]] < mincount
+                   suppresslim*loh[[paste0(vars[ivar], ".y")]]) 
         } else sel = (loh[[paste0(vars[ivar], ".x")]]  <
-                        suppresslim*loh[[paste0(vars[ivar], ".y")]]) # & loh[["countw.x"]] < mincount
+                        suppresslim*loh[[paste0(vars[ivar], ".y")]]) 
         if (sumsmall & sum(sel) == 0) {
           sshare = data.frame(Group.1 = 999999, x = 9999999)
         } else if (sumsmall) {
           #' @importFrom stats aggregate
-          #          sshare = aggregate(loh[[paste0(vars[ivar], "_w", ivar, ".x")]][sel], by = list(loh$ID.y[sel]), sum) 
           sshare = aggregate(loh[[paste0(vars[ivar], ".x")]][sel], by = list(loh$ID.y[sel]), sum) 
           loh$sshare = sshare$x[match(loh$ID.y, sshare$Group.1)]
-          #          loh$sshare[is.na(loh$sshare)] = max(loh[[paste0(vars[ivar], "_w", ivar, ".y")]])
           loh$sshare[is.na(loh$sshare)] = max(loh[[paste0(vars[ivar], ".y")]])
-          #          loh[[paste("hsmall", ivar)]] = loh$sshare <  suppresslimSum*loh[[paste0(vars[ivar], "_w", ivar, ".y")]]
           loh[[paste("hsmall", ivar)]] = loh$sshare <  suppresslimSum*loh[[paste0(vars[ivar], ".y")]]
         } else {
           loh[[paste("hsmall", ivar)]] = sel
